@@ -621,22 +621,52 @@ class CropFaces:
       cropped.save(newFile, "jpeg", quality=100, optimize=True, progressive=True, exif=exif)
     return result
 
+  def cropHeadSquare (self, img, imagePath, exif):
+    face = self.detectBoxFaces(imagePath)
+    if face is not None:
+      print 'face = ' + str(face.left) + ', ' + str(face.top) + ', ' + str(face.right) + ', ' + str(face.bottom)
+      pivotX = face.left + int(face.width / 2)
+      pivotY = face.top + int(face.height / 2)
+      
+      facesize = int(min(10*face.height, min(img.width, img.height)) / 10)
+
+      left = pivotX - (5*facesize)
+      right = pivotX + (5*facesize)
+      top = pivotY - (4*facesize)
+      bottom = pivotY + (6*facesize)
+
+      print 'left = ' + str(left)
+      print 'right = ' + str(right)
+      print 'top = ' + str(top)
+      print 'bottom = ' + str(bottom)
+
+      print 'img.width = ' + str(img.width)
+      print 'img.height = ' + str(img.height)
+
+      if left < 0 or right > img.width or top < 0 or bottom > img.height:
+        fScale = None
+        if right > img.width:
+          fScale = right / img.width
+        elif bottom > img.height:
+          fScale = bottom / img.height
+        if fScale is not None:
+          print 'fScale = ' + str(fScale)
+          left = int(left / fScale)
+          top = int(top / fScale)
+          right = int(right / fScale)
+          bottom = int(bottom / fScale)
+
+      newFile = self.saveCrop(img.crop((left, top, right, bottom)), imagePath, 'face', exif)
+      #self.cropAgainMoreSquares(newFile)
+
+
   def cropAllSquaresHorizontal (self, img, imagePath):
     exif = img.info['exif'] if 'exif' in img.info else None
     size = img.height
     numSplits = int(img.width / size) + 1
     offset = size - int(img.width / numSplits)
 
-    face = self.detectBoxFaces1Head(imagePath)
-    if face is not None:
-      pivotX = int(face.width / 2) + face.left
-      pivotY = face.top + face.height
-      left = pivotX - face.width
-      top = pivotY - int(1.5*face.height)
-      right = pivotX + face.width
-      bottom = pivotY + int(1.5*face.height)
-      newFile = self.saveCrop(img.crop((left, top, right, bottom)), imagePath, 'face', exif)
-      self.cropAgainMoreSquares(newFile)
+    self.cropHeadSquare(img, imagePath, exif)
 
     left = int((img.width - size)/2)
     newFile = self.saveCrop(img.crop((left, 0, left + size, size)), imagePath, 0, exif)
@@ -658,6 +688,8 @@ class CropFaces:
     numSplits = int(img.height / size) + 1
     offset = size - int(img.height / numSplits)
 
+    self.cropHeadSquare(img, imagePath, exif)
+
     top = int((img.height - size)/2)
     newFile = self.saveCrop(img.crop((0, top, size, top + size)), imagePath, 0, exif)
     self.cropAgainMoreSquares(newFile)
@@ -689,9 +721,19 @@ class CropFaces:
         fullpath = os.path.join(folder, filename)
         self.cropAllSquares(fullpath)
 
-
-
-
+  #ffmpeg -i 20150311_125438.mp4 -filter:v fps=fps=1/0.2 ffmpeg_%0d.bmp
+  def videoframes (self, fileVideo):
+    import cv2
+    print(cv2.__version__)
+    vidcap = cv2.VideoCapture(fileVideo)
+    
+    count = 0
+    success = True
+    while success:
+      success,image = vidcap.read()
+      print 'Read a new frame: ', success
+      cv2.imwrite("frame%d.jpg" % count, image)     # save frame as JPEG file
+      count += 1 
 
 #python -c "import sys; import svgmanager; svgmanager.SvgManager.generate(sys.argv)"
 #./cropfaces.py /home/jmramoss/almacen/ORLAS/orlas_infantiles/infantil_5b teacher
